;; Generated package description from cl-generic.el  -*- no-byte-compile: t -*-
(define-package "cl-generic" "0.3.0.20221221.74800" "Forward cl-generic compatibility for Emacs<25" 'nil :commit "27d01353b54ad9b6ad05ecae7f5d94316579c11b" :url "https://elpa.gnu.org/packages/cl-generic.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca"))
